summaryrefslogtreecommitdiffstats
path: root/libkdchart/KDChartDataRegion.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdchart/KDChartDataRegion.h')
-rw-r--r--libkdchart/KDChartDataRegion.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/libkdchart/KDChartDataRegion.h b/libkdchart/KDChartDataRegion.h
index a1d8303..1379043 100644
--- a/libkdchart/KDChartDataRegion.h
+++ b/libkdchart/KDChartDataRegion.h
@@ -29,8 +29,8 @@
#ifndef __KDCHARTDATAREGION__
#define __KDCHARTDATAREGION__
-#include <qregion.h>
-#include <qpointarray.h>
+#include <tqregion.h>
+#include <tqpointarray.h>
#include "KDChartGlobal.h"
@@ -39,35 +39,35 @@
*/
struct KDCHART_EXPORT KDChartDataRegion
{
- typedef QValueList<QPointArray> PointArrayList;
+ typedef TQValueList<TQPointArray> PointArrayList;
KDChartDataRegion()
{
init();
}
- KDChartDataRegion( QRegion region, uint r, uint c, uint ch )
+ KDChartDataRegion( TQRegion region, uint r, uint c, uint ch )
{
init();
- pRegion = new QRegion( region );
+ pRegion = new TQRegion( region );
row = r;
col = c;
chart = ch;
}
- KDChartDataRegion( uint r, uint c, uint ch, QPointArray array )
+ KDChartDataRegion( uint r, uint c, uint ch, TQPointArray array )
{
init();
- pArray = new QPointArray( array );
+ pArray = new TQPointArray( array );
row = r;
col = c;
chart = ch;
}
- KDChartDataRegion( uint r, uint c, uint ch, QRect rect )
+ KDChartDataRegion( uint r, uint c, uint ch, TQRect rect )
{
init();
- pRect = new QRect( rect );
+ pRect = new TQRect( rect );
row = r;
col = c;
chart = ch;
@@ -99,29 +99,29 @@ struct KDCHART_EXPORT KDChartDataRegion
delete pTextRegion;
}
- QRegion region() const
+ TQRegion region() const
{
if( pPointArrayList && ! pPointArrayList->empty() ){
- QRegion region;
+ TQRegion region;
PointArrayList::iterator it;
for ( it = pPointArrayList->begin(); it != pPointArrayList->end(); ++it ){
- region += QRegion( *it );
+ region += TQRegion( *it );
}
return region;
}
if( pRegion )
return *pRegion;
if( pArray )
- return QRegion( *pArray );
+ return TQRegion( *pArray );
if( pRect )
- return QRegion( *pRect );
- return QRegion();
+ return TQRegion( *pRect );
+ return TQRegion();
}
- QRect rect() const
+ TQRect rect() const
{
if( pPointArrayList && ! pPointArrayList->empty() ){
- QRect rect;
+ TQRect rect;
PointArrayList::iterator it;
for ( it = pPointArrayList->begin(); it != pPointArrayList->end(); ++it ){
rect = rect.unite( (*it).boundingRect() );
@@ -134,26 +134,26 @@ struct KDCHART_EXPORT KDChartDataRegion
return pArray->boundingRect();
if( pRect )
return *pRect;
- return QRect();
+ return TQRect();
}
- bool contains(const QPoint & p) const
+ bool tqcontains(const TQPoint & p) const
{
if( pPointArrayList && ! pPointArrayList->empty() ){
PointArrayList::iterator it;
for ( it = pPointArrayList->begin(); it != pPointArrayList->end(); ++it ){
- QRegion region( *it );
- if( region.contains( p ) )
+ TQRegion region( *it );
+ if( region.tqcontains( p ) )
return true;
}
return false;
}
if( pRegion )
- return pRegion->contains( p );
+ return pRegion->tqcontains( p );
if( pArray )
- return QRegion( *pArray ).contains( p );
+ return TQRegion( *pArray ).tqcontains( p );
if( pRect )
- return pRect->contains( p );
+ return pRect->tqcontains( p );
return false;
}
@@ -173,13 +173,13 @@ struct KDCHART_EXPORT KDChartDataRegion
angleLen = 1;
}
- QRegion* pRegion;
- QPointArray* pArray;
- QRect* pRect;
- QRegion* pTextRegion; // for the data values text
+ TQRegion* pRegion;
+ TQPointArray* pArray;
+ TQRect* pRect;
+ TQRegion* pTextRegion; // for the data values text
// for three-dimensional bars, and for comparable structures, needing
// more than one QPointArray, we use this list:
PointArrayList* pPointArrayList;
// For rectangular data representation (bar, line, area, point, ...)
@@ -188,7 +188,7 @@ struct KDCHART_EXPORT KDChartDataRegion
// we store the following additional anchor information:
// store 9 elements: one for each value of KDChartEnums::PositionFlag
- QPointArray points;
+ TQPointArray points;
int startAngle; // Note: 5760 makes a full circle, 2880 is left 'corner'.
int angleLen;
@@ -197,7 +197,7 @@ struct KDCHART_EXPORT KDChartDataRegion
uint col;
// members needed for calculation of data values texts
uint chart;
- QString text; // the data values text
+ TQString text; // the data values text
bool negative; // stores whether the data value is less than zero
};
@@ -207,7 +207,7 @@ struct KDCHART_EXPORT KDChartDataRegion
\brief The collection class used by KD Chart to store data region information.
- This class is derived from QPtrList, so all of the Qt documentation for this class
+ This class is derived from TQPtrList, so all of the TQt documentation for this class
is valid for KDChartDataRegionList too.
\note Normally there is no need to use this class yourself, since it
@@ -221,6 +221,6 @@ struct KDCHART_EXPORT KDChartDataRegion
\sa KDChart, KDChartWidget
*/
-typedef QPtrList < KDChartDataRegion > KDChartDataRegionList;
+typedef TQPtrList < KDChartDataRegion > KDChartDataRegionList;
#endif
@@ -173,13 +173,13 @@ struct KDCHART_EXPORT KDChartDataRegion
// for three-dimensional bars, and for comparable structures, needing
- // more than one QPointArray, we use this list:
+ // more than one TQPointArray, we use this list:
PointArrayList* pPointArrayList;
// For rectangular data representation (bar, line, area, point, ...)